Steps2D

Struct Steps2D 

pub struct Steps2D<T>(pub (T, T, usize), pub (T, T, usize));
Utility for creating evenly spaced steps between two endpoints in 2 dimensions

Example:

use spdcalc::utils::Steps2D;

let arr : Vec<(f64, f64)> = Steps2D((0., 1., 100), (0., 100., 100)).into_iter().collect();
assert_eq!(arr.len(), 100 * 100);
assert!((arr[0].0 - 0.).abs() < 1e-12);
assert!((arr[99].0 - 1.).abs() < 1e-12);
assert!((arr[0].1 - 0.).abs() < 1e-12);
assert!((arr[99].1 - 0.).abs() < 1e-12);
assert!((arr[9999].0 - 1.).abs() < 1e-12);
assert!((arr[9999].1 - 100.).abs() < 1e-12);

Tuple Fields

0: (T, T, usize)1: (T, T, usize)

Implementations

Source

impl<T> Steps2D<T>
where T: Div<f64, Output = T> + Sub<T, Output = T> + Mul<f64, Output = T> + Add<T, Output = T> + Copy,

pub fn new(x: (T, T, usize), y: (T, T, usize)) -> Self

Create a new instance

pub fn divisions(&self) -> (usize, usize)

Number of divisions for each axis

pub fn ranges(&self) -> ((T, T), (T, T))

Range of each axis

pub fn len(&self) -> usize

Total number of steps

pub fn is_empty(&self) -> bool

Is it empty?

pub fn is_square(&self) -> bool

Same number of steps for each axis?

pub fn value(&self, index: usize) -> (T, T)

Get the value at the given index

pub fn swapped(self) -> Steps2D<T>

Swap x and y

pub fn division_widths(&self) -> (T, T)

Get the width of the gap between each step.

Example:
use spdcalc::utils::Steps2D;

let steps = Steps2D((0., 4., 3), (0., 8., 3)); // 3 steps: |0| --- |2| --- |4| and |0| --- |4| --- |8|
let dx = 2.;
let dy = 4.;
assert!((steps.division_widths().0 - dx).abs() < 1e-12);
assert!((steps.division_widths().1 - dy).abs() < 1e-12);