pub type Indices = Unitless<Vector3<f64>>;Expand description
Indices of refraction (n_x, n_y, n_z)
Aliased Type
pub struct Indices {
pub value_unsafe: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
/* private fields */
}Fields
value_unsafe: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>This is the value of whatever type we’re giving units. Using it directly bypasses all of the dimensional analysis that having a unit system provides, and should be avoided whenever possible.
If using this member is necessary, it is strongly encouraged to wrap the calculation in a dimensionally-safe interface.