pub type Wavelength = Meter<f64>;Expand description
Wavelength
Aliased Type
pub struct Wavelength {
pub value_unsafe: f64,
/* private fields */
}Fields
value_unsafe: f64This is the value of whatever type we’re giving units. Using it directly bypasses all of the dimensional analysis that having a unit system provides, and should be avoided whenever possible.
If using this member is necessary, it is strongly encouraged to wrap the calculation in a dimensionally-safe interface.